@@ -13,18 +13,20 @@ import getopt
 
 from tidal_dl.events import *
 from tidal_dl.settings import *
+from tidal_dl.gui import startGui
 
 
 def mainCommand():
     try:
         opts, args = getopt.getopt(sys.argv[1:], 
-                                   "hvl:o:q:r:", 
-                                   ["help", "version", "link=", "output=", "quality", "resolution"])
+                                   "hvgl:o:q:r:", 
+                                   ["help", "version", "gui", "link=", "output=", "quality", "resolution"])
     except getopt.GetoptError as errmsg:
         Printf.err(vars(errmsg)['msg'] + ". Use 'tidal-dl -h' for useage.")
         return
 
     link = None
+    showGui = False
     for opt, val in opts:
         if opt in ('-h', '--help'):
             Printf.usage()
@@ -32,6 +34,9 @@ def mainCommand():
         if opt in ('-v', '--version'):
             Printf.logo()
             return
+        if opt in ('-g', '--gui'):
+            showGui = True
+            continue
         if opt in ('-l', '--link'):
             link = val
             continue
@@ -51,6 +56,10 @@ def mainCommand():
     if not aigpy.path.mkdirs(SETTINGS.downloadPath):
         Printf.err(LANG.MSG_PATH_ERR + SETTINGS.downloadPath)
         return
+    
+    if showGui:
+        startGui()
+        return
 
     if link is not None:
         if not loginByConfig():
@@ -108,7 +117,6 @@ def test():
         
     SETTINGS.audioQuality = AudioQuality.Normal
     SETTINGS.videoFileFormat = VideoQuality.P240
-    SETTINGS.onlyM4a = True
     SETTINGS.checkExist = False
     SETTINGS.includeEP = True
     SETTINGS.saveCovers = True
@@ -124,16 +132,17 @@ def test():
 
     Printf.settings()
     # test example
+    # https://tidal.com/browse/track/70973230
     # track 70973230  77798028 212657
-    # start('70973230')
+    start('70973230')
     # album 58138532  77803199  21993753   79151897  56288918
     # start('58138532')
     # playlist 98235845-13e8-43b4-94e2-d9f8e603cee7
     # start('98235845-13e8-43b4-94e2-d9f8e603cee7')
     # video 155608351 188932980
-    start("155608351")
+    # start("155608351")
 
 
 if __name__ == '__main__':
-    test()
-    # main()
+    # test()
+    main()
