@@ -12,7 +12,6 @@ import json
 import aigpy
 import base64
 import requests
-from urllib.request import urlopen
 
 from tidal_dl.model import *
 from tidal_dl.enums import *
@@ -46,7 +45,7 @@ class TidalAPI(object):
             except Exception as e:
                 if index >= 3:
                     errmsg += respond.text
-                    
+
         raise Exception(errmsg)
 
     def __getItems__(self, path, params={}):
@@ -70,7 +69,9 @@ class TidalAPI(object):
 
     def __getResolutionList__(self, url):
         ret = []
-        array = requests.get(url).text.split("#")
+        txt = requests.get(url).content.decode('utf-8')
+        # array = txt.split("#EXT-X-STREAM-INF")
+        array = txt.split("#")
         for item in array:
             if "RESOLUTION=" not in item:
                 continue
@@ -210,8 +211,8 @@ class TidalAPI(object):
             return self.getMix(id)
         return None
 
-    def search(self, text: str, type: Type, offset: int, limit: int) -> SearchResult:
-        typeStr = Type.Album.name.upper() + "S"
+    def search(self, text: str, type: Type, offset: int = 0, limit: int = 10) -> SearchResult:
+        typeStr = type.name.upper() + "S"
         if type == Type.Null:
             typeStr = "ARTISTS,ALBUMS,TRACKS,VIDEOS,PLAYLISTS"
 
@@ -221,6 +222,19 @@ class TidalAPI(object):
                   "types": typeStr}
         return aigpy.model.dictToModel(self.__get__('search', params=params), SearchResult())
 
+    def getSearchResultItems(self, result: SearchResult, type: Type):
+        if type == Type.Track:
+            return result.tracks.items
+        if type == Type.Video:
+            return result.videos.items
+        if type == Type.Album:
+            return result.albums.items
+        if type == Type.Artist:
+            return result.artists.items
+        if type == Type.Playlist:
+            return result.playlists.items
+        return []
+
     def getLyrics(self, id) -> Lyrics:
         data = self.__get__(f'tracks/{str(id)}/lyrics', urlpre='https://listen.tidal.com/v1/')
         return aigpy.model.dictToModel(data, Lyrics())
@@ -366,10 +380,9 @@ class TidalAPI(object):
                 return item, obj
             except:
                 continue
-            
+
         raise Exception("No result.")
 
+
 # Singleton
 TIDAL_API = TidalAPI()
-
-
